from distutils.core import setup

setup(
    name="newmysci",
    version="1.0.0",
    description="A sample package",
    author="Mhammed",
    author_email="jeddou.ehtp@gmail.com",
    packages=["newmysci"],
    install_requires=[],
)
